Skip to contents

This function computes a relative rigor score based on the indicators provided from an applicant.

Usage

compute_RRS(applicant, sectors = c("weighted", "equal"), verbose = FALSE)

Arguments

applicant

The applicant data that has been imported by the read_RESQUE() and preprocessed by the preprocess() function.

sectors

Should sectors be all equally sized ("equal") or weighted by the maximum sum of attainable points in each category ("weighted")?

verbose

Print extra information.

Value

A tibble containing the dimension (category), maximum points, and relative score for each category, suitable for creating a radar chart.